// Name        : Keith Vertanen
// Username    : kvertanen
// Description : Class that represents a colored ball.

// We need the following line so we can use the Color object in the Java API
import java.awt.*;

public class Ball
{
    // Instance variables
    private double posX   = 0.0;
    private double posY   = 0.0;
    private double radius = 0.0;
    private Color  color  = new Color(0.88f, 0.68f, 1.0f);

    // Construct a Ball object at the given (x, y) position with radius r
    public Ball(double x, double y, double r)
    {
        posX   = x;
        posY   = y;
        radius = r;           
    }

    public void addToX(double deltaX)
    {
        posX += deltaX;
    }
    
    // Figure out if this ball and another ball overlap
    public boolean overlap(Ball other)
    {
        double deltaX = posX - other.posX;
        double deltaY = posY - other.posY;
        double d = Math.sqrt(deltaX * deltaX + deltaY * deltaY);
        if (d < (radius + other.radius))
            return true;
        return false;        
    }       

    // Change the color of this Ball given an RGB pair where r, g, b are 
    // in [0.0, 1.0]
    public void setColor(double r, double g, double b)
    {
        color = new Color((float) r, (float) g, (float) b);
    }

    // Draw this Ball its location in its current color
    public void draw()
    {
        StdDraw.setPenColor(color);
        StdDraw.filledCircle(posX, posY, radius);
    }

    // Text representation of this Ball
    public String toString()
    {
        return "(" + posX + ", " + posY + ") r = " + radius;
    }

}

